[nautilus/wip/antoniof/properties-followup] file: Follow HIG in own username



commit 3dc045bad98d100849f92cecef6470a603cc5835
Author: António Fernandes <antoniof gnome org>
Date:   Thu Aug 4 22:59:11 2022 +0100

    file: Follow HIG in own username
    
    "You" is preferrable to "Me"
    
    https://developer.gnome.org/hig/guidelines/writing-style.html#guidelines

 src/nautilus-file.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/src/nautilus-file.c b/src/nautilus-file.c
index 9ad341983..be2eecde1 100644
--- a/src/nautilus-file.c
+++ b/src/nautilus-file.c
@@ -6825,8 +6825,8 @@ nautilus_file_get_owner_as_string (NautilusFile *file,
     if (include_real_name &&
         file->details->uid == getuid ())
     {
-        /* Translators: "Me" is used to indicate the file is owned by me (the current user) */
-        user_name = g_strdup (_("Me"));
+        /* Translators: This is a username followed by "(You)" to indicate the file is owned by the current 
user */
+        user_name = g_strdup_printf (_("%s (You)"), file->details->owner);
     }
     else if (file->details->owner_real == NULL)
     {


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]